@@ -39,12 +39,14 @@ test_that("Test data from Appendix B are correctly evaluated", {
   expect_known_output(print(res), "NAFTA_SOP_Appendix_B.txt")
 
   plot_nafta <- function() plot(res)
-  vdiffr::expect_doppelganger("NAFTA SOP Appendix B", plot_nafta)
+  if(requireNamespace("vdiffr", quietly = TRUE)) {
+    vdiffr::expect_doppelganger("NAFTA SOP Appendix B", plot_nafta)
+  }
 })
 
 test_that("Test data from Appendix D are correctly evaluated", {
-  expect_warning(res <- nafta(NAFTA_SOP_Appendix_D, "MRID 555555", 
-                              cores = 1, quiet = TRUE))
+  res <- nafta(NAFTA_SOP_Appendix_D, "MRID 555555", 
+                              cores = 1, quiet = TRUE)
 
   # From Figure D.1
   dtx_sop <- matrix(c(407, 541, 429, 1352, 5192066, 2383), nrow = 3, ncol = 2)
@@ -61,5 +63,7 @@ test_that("Test data from Appendix D are correctly evaluated", {
   expect_known_output(print(res), "NAFTA_SOP_Appendix_D.txt")
 
   plot_nafta <- function() plot(res)
-  vdiffr::expect_doppelganger("Plot NAFTA analysis", plot_nafta)
+  if(requireNamespace("vdiffr", quietly = TRUE)) {
+    vdiffr::expect_doppelganger("Plot NAFTA analysis", plot_nafta)
+  }
 })
